@@ -75,10 +75,18 @@ class JsonHtmlConverter(BaseConverter):
         )
         data = htmlwriter.JsonConverter(formatter).convert(libdoc)
 
+        # Format keyword shortdoc with correct formatter, strip extra HTML tags
         for keyword in data["keywords"]:
             shortdoc = formatter.html(keyword["shortdoc"])
-            shortdoc = re.search(r"<p>(.*)<\/p>", shortdoc).group(1)
-            keyword["shortdoc"] = shortdoc
+            shortdoc = re.search(r"<p>(.*)<\/p>", shortdoc)
+
+            if shortdoc is None:
+                logging.warning(
+                    "Missing shortdoc: %s.%s", data["name"], keyword["name"]
+                )
+                continue
+
+            keyword["shortdoc"] = shortdoc.group(1)
 
         with open(output, "w") as fd:
             json.dump(data, fd, indent=4)
